pub enum ParseError {
Xml(Error),
Io {
path: PathBuf,
source: Error,
},
BadAttribute {
tag: String,
attr: String,
message: String,
},
BadAttributeValue {
tag: String,
attr: String,
value: String,
message: String,
},
BadInclude {
file: PathBuf,
message: String,
},
UnknownClass {
tag: String,
class: String,
},
Unsupported {
feature: String,
hint: Option<String>,
},
InvalidModel(String),
}Expand description
Errors that can be returned while parsing an MJCF document.
Variants
Xml(Error)
The XML failed to parse.
Io
I/O error while reading a file (or one of its <include> targets).
BadAttribute
An attribute couldn’t be parsed.
BadAttributeValue
An attribute had an unexpected value.
Fields
BadInclude
<include> referenced a file that wasn’t found, or formed a cycle.
UnknownClass
<element class="…"> referenced a class that doesn’t exist.
Unsupported
A feature is parsed but not supported by this version of the loader.
InvalidModel(String)
A body referenced a parent that wasn’t found.